@@ -1,7 +1,5 @@
 from flask_modals.modal import (
     Modal,
     render_template_modal,
-    render_template_redirect,
-    redirect_to,
     response
 )
